@@ -82,12 +82,7 @@ def publish(dag_path, phs3):
                             dv.DAGS_S3_PHJOBS_PATH + key + "/args.properties")
 
 
-def submit_conf(path, phs3):
-    stream = phs3.open_object(dv.DAGS_S3_BUCKET, dv.DAGS_S3_PHJOBS_PATH + path + "/phconf.yaml")
-    config = PhYAMLConfig(path)
-    config.load_yaml(stream)
-    runtime = config.spec.containers.runtime
-
+def submit_conf(path, phs3, runtime):
     return {
         "spark.pyspark.python": "/usr/bin/"+runtime,
         "jars": "s3a://ph-stream/jars/aws/aws-java-sdk-1.11.682.jar,"
