@@ -16,8 +16,6 @@ from ph_logs.ph_logs import phlogger
 from ph_errs.ph_err import PhException, PhRuntimeError
 from ph_errs.ph_err import exception_file_already_exist, exception_file_not_exist, exception_function_not_implement
 from ph_max_auto import define_value as dv
-from ph_max_auto.ph_runtime import ph_python3
-from ph_max_auto.ph_runtime import ph_r
 from ph_max_auto.phconfig.phconfig import PhYAMLConfig
 
 phsts = PhSts().assume_role(
@@ -140,7 +138,12 @@ class PhContextFacade(object):
         return ast_dict
 
     def get_runtime_inst(self, runtime):
+        from ph_max_auto.ph_runtime import ph_python3
+        from ph_max_auto.ph_runtime import ph_r
+
         table = {
+            "python": ph_python3,
+            "python2": ph_python3,
             "python3": ph_python3,
             "r": ph_r,
         }
@@ -183,7 +186,11 @@ class PhContextFacade(object):
     def command_publish_exec(self):
         phlogger.info("command publish")
 
-        runtime_inst = self.get_runtime_inst(self.runtime)
+        config = PhYAMLConfig(self.path)
+        config.load_yaml()
+        runtime = config.spec.containers.runtime
+
+        runtime_inst = self.get_runtime_inst(runtime)
         runtime_inst.publish(
             dag_path=self.dag_path,
             phs3=phs3,
@@ -306,7 +313,11 @@ class PhContextFacade(object):
         phlogger.info("submit command with context " + str(self.context))
         phlogger.info("submit command with args " + str(self.args))
 
-        runtime_inst = self.get_runtime_inst(self.runtime)
+        stream = phs3.open_object(dv.DAGS_S3_BUCKET, dv.DAGS_S3_PHJOBS_PATH + self.path + "/phconf.yaml")
+        config = PhYAMLConfig(self.path)
+        config.load_yaml(stream)
+        runtime = config.spec.containers.runtime
+        runtime_inst = self.get_runtime_inst(runtime)
         submit_prefix = "s3a://" + dv.DAGS_S3_BUCKET + "/" + dv.DAGS_S3_PHJOBS_PATH + self.path + "/"
         args = phs3.open_object_by_lines(dv.DAGS_S3_BUCKET, dv.DAGS_S3_PHJOBS_PATH + self.path + "/args.properties")
 
@@ -334,7 +345,7 @@ class PhContextFacade(object):
             "spark.hadoop.fs.s3a.secret.key": secret_key,
             "spark.hadoop.fs.s3a.endpoint": "s3.cn-northwest-1.amazonaws.com.cn"
         }
-        conf_map.update(runtime_inst.submit_conf(self.path, phs3))
+        conf_map.update(runtime_inst.submit_conf(self.path, phs3, runtime))
         conf_map.update(dict([(k.lstrip("CONF__"), v) for k, v in self.context.items() if k.startswith('CONF__')]))
         conf_map = [('--conf', k + '=' + v) for k, v in conf_map.items()]
         cmd_arr += [j for i in conf_map for j in i]
